# ♆ NEPTUNE

**NEPTUNE** is a set of decoupled **Python libraries** intended to facilitate Python development:
* nfin,
* ngui,
* nlearn,
* nmath and
* nutil.

The library **nfin** contains financial utility functions; among them:
* time series manipulation and
* pricing engine (including Black-Scholes model).

NEPTUNE is based on popular libraries like numpy, pandas, plotly and scipy.

## Install

Launch the following commands in a shell:

~~~bash
git clone https://github.com/b-io/io.barras.git
cd io.barras/python/neptune/
mvn clean install
~~~

## License

Feel free to download, try and share your suggestions about the libraries,
while respecting [this MIT License (MIT)][license].

[license]: <LICENSE>
